import java.util.Arrays;
import java.util.Comparator;
import java.util.Optional;

class Point {
	int x;
	int y;

	public Point(int x2, int y2) {
		this.x = x2;
		this.y = y2;
	}

	public Point(String arg) {
		String[] split = arg.split(",");
		x = Integer.parseInt(split[0]);
		y = Integer.parseInt(split[1]);
	}

	public double getOrigDist() {
		return Math.sqrt(x * x + y * y);
	}

	@Override
	public String toString() {
		return String.format("(%d,%d)", x, y);
		// return "(" + x + "," + y + ")";
	}

	public boolean isFartherFromOrig(Point p2) {
		return getOrigDist() > p2.getOrigDist();
	}
}

public class Bevezeto {
	public static void main(String[] args) {
		// args = "3,6 123,334 -324,63".split(" ");
		
		// printMaxV1(args);
		// printMaxV2(args);

		args = "3 6 123 334 -324 63".split(" ");

		printSortedArgs(args);
	}

	private static void printSortedArgs(String[] args) {
		System.out.println("a".compareTo("b"));
		System.out.println("a".compareTo("a"));
		System.out.println("b".compareTo("a"));

		Arrays.sort(args);

		System.out.println(args);
		System.out.println(Arrays.toString(args));

		Arrays.sort(
				args,
				(arg1, arg2) -> Integer.valueOf(arg1).compareTo(
						Integer.valueOf(arg2)));

		System.out.println(Arrays.toString(args));

		Arrays.sort(args, new Comparator<String>() {
			@Override
			public int compare(String arg1, String arg2) {
				return Integer.valueOf(arg1).compareTo(Integer.valueOf(arg2));
			}
		});

		System.out.println(Arrays.toString(args));
	}

	private static void printMaxV1(String[] args) {
		Point[] points = argsToPoints(args);
		Point max = findMax(points);
		System.out.println(max);
	}

	private static Point findMax(Point[] points) {
		Point max = points[0];
		for (Point point : points) {
			if (max.getOrigDist() < point.getOrigDist())
				max = point;
		}
		return max;
	}

	private static void printMaxV2(String[] args) {
		Optional<Point> max2 = Arrays
				.stream(args)
				.map(arg -> new Point(arg))
				.max((p1, p2) -> new Double(p1.getOrigDist()).compareTo(p2
						.getOrigDist()));
		System.out.println(max2.get());
	}

	private static Point[] argsToPoints(String[] args) {
		Point[] points = new Point[args.length];

		int idx = 0;
		for (String arg : args) {
			String[] split = arg.split(",");
			int x = Integer.parseInt(split[0]);
			int y = Integer.parseInt(split[1]);
			points[idx] = new Point(x, y);
			++idx;
		}
		return points;
	}
}
